@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -122,7 +122,7 @@ get_full_uri (DlgNewData *data)
     idx = egg_file_format_chooser_get_format (EGG_FILE_FORMAT_CHOOSER (data->format_chooser), uri);
     if (idx > 0) {
         const char *uri_ext;
-        char       *default_ext;
+        const char *default_ext;
 
         uri_ext = get_archive_filename_extension (uri);
         default_ext = mime_type_desc[data->supported_types[idx-1]].default_ext;
@@ -209,7 +209,7 @@ get_archive_filename_from_selector (DlgNewData *data)
     if (get_archive_filename_extension (uri) == NULL) {
         int   idx;
         char *new_uri;
-        char *ext = NULL;
+        const char *ext = NULL;
 
         idx = egg_file_format_chooser_get_format (EGG_FILE_FORMAT_CHOOSER (data->format_chooser), uri);
         if (idx > 0)
@@ -224,9 +224,9 @@ get_archive_filename_from_selector (DlgNewData *data)
     debug (DEBUG_INFO, "create/save %s\n", uri);
 
     if (uri_exists (uri)) {
-        GtkWidget *dialog;
 
         if (! is_supported_extension (data->dialog, uri, data->supported_types)) {
+            GtkWidget *dialog;
             dialog = _gtk_error_dialog_new (GTK_WINDOW (data->dialog),
                             GTK_DIALOG_MODAL,
                             NULL,
@@ -898,7 +898,7 @@ activate_action_about (GtkAction *action,
     gtk_show_about_dialog (GTK_WINDOW (window),
                    "version", VERSION,
                    "copyright", _("Copyright \xc2\xa9 2001–2010 Free Software Foundation, Inc.\n"
-                                  "Copyright \xc2\xa9 2012–2019 The MATE developers"),
+                                  "Copyright \xc2\xa9 2012–2020 The MATE developers"),
                    "comments", _("An archive manager for MATE."),
                    "authors", authors,
                    "documenters", documenters,
@@ -906,7 +906,7 @@ activate_action_about (GtkAction *action,
                    "logo-icon-name", "engrampa",
                    "license", license_text,
                    "wrap-license", TRUE,
-                   "website", "http://mate-desktop.org",
+                   "website", "https://mate-desktop.org",
                    NULL);
 
     g_strfreev (authors);
