@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -878,8 +878,8 @@ save_options_cb (GtkWidget  *w,
 				_("_Options Name:"),
 				(data->last_options != NULL) ? data->last_options : "",
 				1024,
-				"gtk-cancel",
-				"gtk-save");
+				_("_Cancel"),
+				_("_Save"));
 	if (opt_filename == NULL)
 		return;
 
