@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -42,7 +42,7 @@
 #include "fr-process.h"
 #include "fr-init.h"
 
-#if ENABLE_MAGIC
+#ifdef ENABLE_MAGIC
 #include <magic.h>
 #endif
 
@@ -203,7 +203,8 @@ fr_archive_get_type (void)
 			NULL,
 			sizeof (FrArchive),
 			0,
-			(GInstanceInitFunc) fr_archive_init
+			(GInstanceInitFunc) fr_archive_init,
+			NULL
 		};
 
 		type = g_type_register_static (G_TYPE_OBJECT,
@@ -276,7 +277,7 @@ fr_archive_class_init (FrArchiveClass *class)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (FrArchiveClass, stoppable),
 			      NULL, NULL,
-			      fr_marshal_VOID__BOOL,
+			      fr_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE,
 			      1, G_TYPE_BOOLEAN);
 	fr_archive_signals[WORKING_ARCHIVE] =
@@ -515,7 +516,7 @@ get_mime_type_from_content (GFile *file)
 static const char *
 get_mime_type_from_magic_numbers (GFile *file)
 {
-#if ENABLE_MAGIC
+#ifdef ENABLE_MAGIC
 	static magic_t magic = NULL;
 
 	if (! magic) {
@@ -549,25 +550,31 @@ get_mime_type_from_magic_numbers (GFile *file)
 		const char * const mime_type;
 	} magic_ids [] = {
 		/* magic ids taken from magic/Magdir/archive from the file-4.21 tarball */
+		{ 0, 21, "!<arch>" "\x0a" "debian-binary",       "application/vnd.debian.binary-package" },
+		{ 0,  8, "!<arch>" "\x0a",                       "application/x-archive"       },
 		{ 0,  6, "7z\274\257\047\034",                   "application/x-7z-compressed" },
 		{ 7,  7, "**ACE**",                              "application/x-ace"           },
 		{ 0,  2, "\x60\xea",                             "application/x-arj"           },
 		{ 0,  4, "\xce\xb2\xcf\x81",                     "application/x-brotli"        },
 		{ 0,  3, "BZh",                                  "application/x-bzip2"         },
 		{ 0,  2, "\037\213",                             "application/x-gzip"          },
+		{ 2,  3, "-lh",                                  "application/x-lzh-compressed"},
 		{ 0,  4, "LZIP",                                 "application/x-lzip"          },
 		{ 0,  9, "\x89\x4c\x5a\x4f\x00\x0d\x0a\x1a\x0a", "application/x-lzop",         },
 		{ 0,  4, "Rar!",                                 "application/x-rar"           },
+		{ 0,  4, "\xed\xab\xee\xdb",                     "application/x-rpm"           },
 		{ 0,  4, "RZIP",                                 "application/x-rzip"          },
 		{ 0,  6, "\3757zXZ\000",                         "application/x-xz"            },
 		{ 20, 4, "\xdc\xa7\xc4\xfd",                     "application/x-zoo",          },
 		{ 0,  4, "PK\003\004",                           "application/zip"             },
 		{ 0,  8, "PK00PK\003\004",                       "application/zip"             },
 		{ 0,  4, "LRZI",                                 "application/x-lrzip"         },
+		{ 0,  2, "\x1f\x9d",                             "application/x-compress"      }, /* using Lempel-Ziv-Welch   algorithm */
+		{ 0,  2, "\x1f\xa0",                             "application/x-compress"      }, /* using Lempel-Ziv-Huffman algorithm */
 	};
 
-	char buffer[32];
-	int  i;
+	char   buffer[32];
+	size_t i;
 
 	if (! g_load_file_in_buffer (file, buffer, sizeof (buffer), NULL))
 		return NULL;
@@ -686,8 +693,8 @@ action_started (FrCommand *command,
 		FrAction   action,
 		FrArchive *archive)
 {
-#ifdef DEBUG
-	debug (DEBUG_INFO, "%s [START] (FR::Archive)\n", action_names[action]);
+#ifdef MATE_ENABLE_DEBUG
+	debug (DEBUG_INFO, "%s [START] (FR::Archive)\n", get_action_name (action));
 #endif
 
 	g_signal_emit (G_OBJECT (archive),
@@ -923,8 +930,8 @@ action_performed (FrCommand   *command,
 		  FrProcError *error,
 		  FrArchive   *archive)
 {
-#ifdef DEBUG
-	debug (DEBUG_INFO, "%s [DONE] (FR::Archive)\n", action_names[action]);
+#ifdef MATE_ENABLE_DEBUG
+	debug (DEBUG_INFO, "%s [DONE] (FR::Archive)\n", get_action_name (action));
 #endif
 
 	switch (action) {
@@ -2517,7 +2524,7 @@ delete_from_archive (FrArchive *archive,
 	/* file_list == NULL means delete all the files in the archive. */
 
 	if (file_list == NULL) {
-		int i;
+		guint i;
 
 		for (i = 0; i < archive->command->files->len; i++) {
 			FileData *fdata = g_ptr_array_index (archive->command->files, i);
@@ -3073,7 +3080,7 @@ fr_archive_extract_to_local (FrArchive  *archive,
 
 	extract_all = (file_list == NULL);
 	if (extract_all && (! all_options_supported || ! archive->command->propCanExtractAll)) {
-		int i;
+		guint i;
 
 		file_list = NULL;
 		for (i = 0; i < archive->command->files->len; i++) {
@@ -3126,7 +3133,7 @@ fr_archive_extract_to_local (FrArchive  *archive,
 				 && ! archive->command->propExtractCanJunkPaths)));
 
 	if (extract_all && ! file_list_created) {
-		int i;
+		guint i;
 
 		file_list = NULL;
 		for (i = 0; i < archive->command->files->len; i++) {
