@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <stdio.h>
@@ -129,7 +129,7 @@ list__process_line (char     *line,
 			comm->multi_volume = (strcmp (fields[1], "+") == 0);
 			g_strfreev (fields);
 		}
-		else if (strncmp (line, "Unexpected end of archive", 25) == 0)  { 
+		else if (strncmp (line, "Unexpected end of archive", 25) == 0)  {
 			unexpected_end_of_archive = TRUE;
 		}
 		return;
@@ -332,7 +332,6 @@ fr_command_7z_add (FrCommand     *comm,
 
 	if (base_dir != NULL) {
 		fr_process_set_working_dir (comm->process, base_dir);
-		fr_process_add_arg_concat (comm->process, "-w", base_dir, NULL);
 	}
 
 	if (is_mime_type (comm->mime_type, "application/zip")
@@ -746,7 +745,8 @@ fr_command_7z_get_type ()
 			NULL,
 			sizeof (FrCommand7z),
 			0,
-			(GInstanceInitFunc) fr_command_7z_init
+			(GInstanceInitFunc) fr_command_7z_init,
+			NULL
 		};
 
 		type = g_type_register_static (FR_TYPE_COMMAND,
