@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -48,10 +48,10 @@ mktime_from_string (char *month,
 		    char *mday,
 		    char *time_or_year)
 {
-	static char  *months[] = { "Jan", "Feb", "Mar", "Apr", "May", "Jun",
-				   "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
-	struct tm     tm = {0, };
-	char        **fields;
+	static const char *months[] = { "Jan", "Feb", "Mar", "Apr", "May", "Jun",
+                                         "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
+	struct tm   tm = {0, };
+	char      **fields;
 
 	tm.tm_isdst = -1;
 
@@ -309,7 +309,17 @@ fr_command_lha_extract (FrCommand  *comm,
 }
 
 
-const char *lha_mime_type[] = { "application/x-lha", NULL };
+static void
+fr_command_lha_test (FrCommand   *comm)
+{
+	fr_process_begin_command (comm->process, "lha");
+	fr_process_add_arg (comm->process, "t");
+	fr_process_add_arg (comm->process, comm->filename);
+	fr_process_end_command (comm->process);
+}
+
+
+const char *lha_mime_type[] = { "application/x-lzh-compressed", "application/x-lha",  NULL };
 
 
 static const char **
@@ -357,6 +367,7 @@ fr_command_lha_class_init (FrCommandLhaClass *class)
 	afc->add              = fr_command_lha_add;
 	afc->delete           = fr_command_lha_delete;
 	afc->extract          = fr_command_lha_extract;
+	afc->test             = fr_command_lha_test;
 	afc->get_mime_types   = fr_command_lha_get_mime_types;
 	afc->get_capabilities = fr_command_lha_get_capabilities;
 	afc->get_packages     = fr_command_lha_get_packages;
@@ -373,7 +384,7 @@ fr_command_lha_init (FrCommand *comm)
 	comm->propExtractCanSkipOlder      = FALSE;
 	comm->propExtractCanJunkPaths      = TRUE;
 	comm->propPassword                 = FALSE;
-	comm->propTest                     = FALSE;
+	comm->propTest                     = TRUE;
 }
 
 
@@ -404,7 +415,8 @@ fr_command_lha_get_type ()
 			NULL,
 			sizeof (FrCommandLha),
 			0,
-			(GInstanceInitFunc) fr_command_lha_init
+			(GInstanceInitFunc) fr_command_lha_init,
+			NULL
 		};
 
 		type = g_type_register_static (FR_TYPE_COMMAND,
