@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <stdio.h>
@@ -89,7 +89,7 @@ Details: RAR 4
  Attributes      Size    Packed Ratio   Date   Time   Checksum  Name
 ----------- ---------  -------- ----- -------- -----  --------  ----
  -rw-rw-r--      3165      1310  41%  07-03-17 21:34  888D50B3  loremipsum.txt
- -rw-rw-r--         0         8   0%  07-03-17 21:36  00000000  file2.empty 
+ -rw-rw-r--         0         8   0%  07-03-17 21:36  00000000  file2.empty
 ----------- ---------  -------- ----- -------- -----  --------  ----
                  3165      1318  41%                            2
 
@@ -702,7 +702,7 @@ fr_command_rar_handle_error (FrCommand   *comm,
 			error->type = FR_PROC_ERROR_ASK_PASSWORD;
 			break;
 		}
-		
+
 		if (strncmp (line, "Unexpected end of archive", 25) == 0) {
 			/* FIXME: handle this type of errors at a higher level when the freeze is over. */
 		}
@@ -828,7 +828,8 @@ fr_command_rar_get_type ()
 			NULL,
 			sizeof (FrCommandRar),
 			0,
-			(GInstanceInitFunc) fr_command_rar_init
+			(GInstanceInitFunc) fr_command_rar_init,
+			NULL
 		};
 
 		type = g_type_register_static (FR_TYPE_COMMAND,
