@@ -17,9 +17,11 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#define _XOPEN_SOURCE 700
+
 #include <config.h>
 
 #include <sys/types.h>
@@ -39,6 +41,7 @@
 #include "fr-command-tar.h"
 
 #define ACTIVITY_DELAY 20
+#define LSTAR_DATE_FORMAT "%Y-%m-%d %H:%M"
 
 static void fr_command_tar_class_init  (FrCommandTarClass *class);
 static void fr_command_tar_init        (FrCommand         *afile);
@@ -52,40 +55,11 @@ static FrCommandClass *parent_class = NULL;
 /* -- list -- */
 
 static time_t
-mktime_from_string (char *date_s,
-		    char *time_s)
+mktime_from_string (const char *time_s)
 {
-	struct tm   tm = {0, };
-	char      **fields;
-
+	struct tm tm = {0, };
 	tm.tm_isdst = -1;
-
-	/* date */
-
-	fields = g_strsplit (date_s, "-", 3);
-	if (fields[0] != NULL) {
-		tm.tm_year = atoi (fields[0]) - 1900;
-		if (fields[1] != NULL) {
-			tm.tm_mon = atoi (fields[1]) - 1;
-			if (fields[2] != NULL)
-				tm.tm_mday = atoi (fields[2]);
-		}
-	}
-	g_strfreev (fields);
-
-	/* time */
-
-	fields = g_strsplit (time_s, ":", 3);
-	if (fields[0] != NULL) {
-		tm.tm_hour = atoi (fields[0]);
-		if (fields[1] != NULL) {
-			tm.tm_min  = atoi (fields[1]);
-			if (fields[2] != NULL)
-				tm.tm_sec  = atoi (fields[2]);
-		}
-	}
-	g_strfreev (fields);
-
+	strptime (time_s, LSTAR_DATE_FORMAT, &tm);
 	return mktime (&tm);
 }
 
@@ -107,15 +81,15 @@ tar_get_last_field (const char *line,
 	while ((field_n > 0) && (*f_end != 0)) {
 		if (*f_end == ' ') {
 			field_n--;
-			if (field_n != 0) {
-				while ((*f_end == ' ') && (*f_end != *line))
-					f_end++;
+			if (field_n == 1)
 				f_start = f_end;
-			}
-		} else
-			f_end++;
+		}
+		f_end++;
 	}
 
+	if (*f_start == ' ')
+		f_start++;
+
 	return g_strdup (f_start);
 }
 
@@ -128,7 +102,7 @@ process_line (char     *line,
 	FrCommand   *comm = FR_COMMAND (data);
 	char       **fields;
 	int          date_idx;
-	char        *field_date, *field_time, *field_size, *field_name;
+	char        *field_date, *field_size, *field_name;
 	char        *name;
 
 	g_return_if_fail (line != NULL);
@@ -143,11 +117,9 @@ process_line (char     *line,
 	fdata->size = g_ascii_strtoull (field_size, NULL, 10);
 	g_free (field_size);
 
-	field_date = file_list__get_next_field (line, date_idx, 1);
-	field_time = file_list__get_next_field (line, date_idx, 2);
-	fdata->modified = mktime_from_string (field_date, field_time);
+	field_date = g_strndup (line + date_idx, 16);
+	fdata->modified = mktime_from_string (field_date);
 	g_free (field_date);
-	g_free (field_time);
 
 	/* Full path */
 
@@ -855,6 +827,11 @@ get_uncompressed_name (FrCommandTar *c_tar,
 		if (file_extension_is (e_filename, ".tar.7z"))
 			new_name[l - 3] = 0;
 	}
+	else if (is_mime_type (comm->mime_type, "application/x-zstd-compressed-tar")) {
+		/* X.tar.zst -->  X.tar */
+		if (file_extension_is (e_filename, ".tar.zst"))
+			new_name[l - 4] = 0;
+	}
 
 	return new_name;
 }
@@ -1008,6 +985,14 @@ fr_command_tar_uncompress (FrCommand *comm)
 			fr_process_add_arg (comm->process, tmp_name);
 			fr_process_end_command (comm->process);
 		}
+		else if (is_mime_type (comm->mime_type, "application/x-zstd-compressed-tar")) {
+			fr_process_begin_command (comm->process, "zstd");
+			fr_process_set_begin_func (comm->process, begin_func__uncompress, comm);
+			fr_process_add_arg (comm->process, "-f");
+			fr_process_add_arg (comm->process, "-d");
+			fr_process_add_arg (comm->process, tmp_name);
+			fr_process_end_command (comm->process);
+		}
 	}
 
 	c_tar->uncomp_filename = get_uncompressed_name (c_tar, tmp_name);
@@ -1037,6 +1022,7 @@ const char *tar_mime_types[] = { "application/x-compressed-tar",
 			         "application/x-lzop-compressed-tar",
 			         "application/x-tarz",
 				 "application/x-xz-compressed-tar",
+				 "application/x-zstd-compressed-tar",
 			         NULL };
 
 
@@ -1102,8 +1088,8 @@ fr_command_tar_get_capabilities (FrCommand  *comm,
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
 	else if (is_mime_type (mime_type, "application/x-7z-compressed-tar")) {
-		char *try_command[3] = { "7za", "7zr", "7z" };
-		int   i;
+		const char *try_command[3] = { "7za", "7zr", "7z" };
+		size_t i;
 
 		for (i = 0; i < G_N_ELEMENTS (try_command); i++) {
 			if (is_program_available (try_command[i], check_command)) {
@@ -1112,6 +1098,10 @@ fr_command_tar_get_capabilities (FrCommand  *comm,
 			}
 		}
 	}
+	else if (is_mime_type (mime_type, "application/x-zstd-compressed-tar")) {
+		if (is_program_available ("zstd", check_command))
+			capabilities |= FR_COMMAND_CAN_READ;
+	}
 
 	return capabilities;
 }
@@ -1126,8 +1116,8 @@ fr_command_tar_set_mime_type (FrCommand  *comm,
 	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
 
 	if (is_mime_type (mime_type, "application/x-7z-compressed-tar")) {
-		char *try_command[3] = { "7za", "7zr", "7z" };
-		int   i;
+		const char *try_command[3] = { "7za", "7zr", "7z" };
+		size_t i;
 
 		for (i = 0; i < G_N_ELEMENTS (try_command); i++) {
 			if (is_program_in_path (try_command[i])) {
@@ -1165,6 +1155,8 @@ fr_command_tar_get_packages (FrCommand  *comm,
 		return PACKAGES ("tar,lzop");
 	else if (is_mime_type (mime_type, "application/x-7z-compressed-tar"))
 		return PACKAGES ("tar,p7zip");
+	else if (is_mime_type (mime_type, "application/x-zstd-compressed-tar"))
+		return PACKAGES ("tar,zstd");
 
 	return NULL;
 }
@@ -1263,7 +1255,8 @@ fr_command_tar_get_type ()
 			NULL,
 			sizeof (FrCommandTar),
 			0,
-			(GInstanceInitFunc) fr_command_tar_init
+			(GInstanceInitFunc) fr_command_tar_init,
+			NULL
 		};
 
 		type = g_type_register_static (FR_TYPE_COMMAND,
