@@ -17,9 +17,10 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <config.h>
 #include <string.h>
 #include <stdio.h>
 #include <glib.h>
@@ -35,16 +36,6 @@
 /* gobject utils*/
 
 
-gpointer
-_g_object_ref (gpointer object)
-{
-	if (object != NULL)
-		return g_object_ref (object);
-	else
-		return NULL;
-}
-
-
 void
 _g_object_unref (gpointer object)
 {
@@ -185,14 +176,6 @@ escape_str (const char *str,
 }
 
 
-/* escape with backslash the file name. */
-char*
-shell_escape (const char *filename)
-{
-	return escape_str (filename, "$'`\"\\!?* ()[]&|:;<>#");
-}
-
-
 static const char *
 g_utf8_strstr (const char *haystack, const char *needle)
 {
@@ -326,20 +309,20 @@ match_regexps (GRegex           **regexps,
 {
 	gboolean matched;
 	int      i;
-	
+
 	if ((regexps == NULL) || (regexps[0] == NULL))
 		return TRUE;
 
 	if (string == NULL)
 		return FALSE;
-	
+
 	matched = FALSE;
 	for (i = 0; regexps[i] != NULL; i++)
 		if (g_regex_match (regexps[i], string, match_options, NULL)) {
 			matched = TRUE;
 			break;
 		}
-		
+
 	return matched;
 }
 
@@ -348,10 +331,10 @@ void
 free_regexps (GRegex **regexps)
 {
 	int i;
-	
-	if (regexps == NULL) 
+
+	if (regexps == NULL)
 		return;
-		
+
 	for (i = 0; regexps[i] != NULL; i++)
 		g_regex_unref (regexps[i]);
 	g_free (regexps);
@@ -370,11 +353,11 @@ search_util_get_patterns (const char *pattern_string)
 	patterns = g_utf8_strsplit (pattern_string, ";", MAX_PATTERNS);
 	for (i = 0; patterns[i] != NULL; i++) {
 		char *p1, *p2;
-		
+
 		p1 = g_utf8_strstrip (patterns[i]);
 		p2 = str_substitute (p1, ".", "\\.");
 		patterns[i] = str_substitute (p2, "*", ".*");
-		
+
 		g_free (p2);
 		g_free (p1);
 	}
@@ -390,51 +373,23 @@ search_util_get_regexps (const char         *pattern_string,
 	char   **patterns;
 	GRegex **regexps;
 	int      i;
-		
+
 	patterns = search_util_get_patterns (pattern_string);
 	if (patterns == NULL)
 		return NULL;
-		
+
 	regexps = g_new0 (GRegex*, n_fields (patterns) + 1);
-	for (i = 0; patterns[i] != NULL; i++) 
-		regexps[i] = g_regex_new (patterns[i], 
-					  G_REGEX_OPTIMIZE | compile_options, 
-					  G_REGEX_MATCH_NOTEMPTY, 
+	for (i = 0; patterns[i] != NULL; i++)
+		regexps[i] = g_regex_new (patterns[i],
+					  G_REGEX_OPTIMIZE | compile_options,
+					  G_REGEX_MATCH_NOTEMPTY,
 					  NULL);
 	g_strfreev (patterns);
-	
+
 	return regexps;
 }
 
 
-char *
-_g_strdup_with_max_size (const char *s,
-			 int         max_size)
-{
-	char *result;
-	int   l = strlen (s);
-
-	if (l > max_size) {
-		char *first_half;
-		char *second_half;
-		int   offset;
-		int   half_max_size = max_size / 2 + 1;
-
-		first_half = g_strndup (s, half_max_size);
-		offset = half_max_size + l - max_size;
-		second_half = g_strndup (s + offset, half_max_size);
-
-		result = g_strconcat (first_half, "...", second_half, NULL);
-
-		g_free (first_half);
-		g_free (second_half);
-	} else
-		result = g_strdup (s);
-
-	return result;
-}
-
-
 const char *
 eat_spaces (const char *line)
 {
@@ -446,17 +401,6 @@ eat_spaces (const char *line)
 }
 
 
-const char *
-eat_void_chars (const char *line)
-{
-	if (line == NULL)
-		return NULL;
-	while (((*line == ' ') || (*line == '\t')) && (*line != 0))
-		line++;
-	return line;
-}
-
-
 char **
 split_line (const char *line,
 	    int         n_fields)
@@ -529,7 +473,7 @@ debug (const char *file,
        const char *function,
        const char *format, ...)
 {
-#ifdef DEBUG
+#ifdef MATE_ENABLE_DEBUG
 	va_list  args;
 	char    *str;
 
@@ -547,27 +491,6 @@ debug (const char *file,
 }
 
 
-char *
-get_time_string (time_t time)
-{
-	struct tm *tm;
-	char       s_time[256];
-	char      *locale_format = NULL;
-	char      *time_utf8;
-
-	tm = localtime (&time);
-	/* This is the time format used in the "Date Modified" column and
-	 * in the Properties dialog.  See the man page of strftime for an 
-	 * explanation of the values. */
-	locale_format = g_locale_from_utf8 (_("%d %B %Y, %H:%M"), -1, NULL, NULL, NULL);
-	strftime (s_time, sizeof (s_time) - 1, locale_format, tm);
-	g_free (locale_format);
-	time_utf8 = g_locale_to_utf8 (s_time, -1, NULL, NULL, NULL);
-
-	return time_utf8;
-}
-
-
 void
 g_ptr_array_free_full (GPtrArray *array,
                        GFunc      free_func,
@@ -578,45 +501,6 @@ g_ptr_array_free_full (GPtrArray *array,
 }
 
 
-void
-g_ptr_array_reverse (GPtrArray *array)
-{
-	int      i, j;
-	gpointer tmp;
-	
-	for (i = 0; i < array->len / 2; i++) {
-		j = array->len - i - 1;
-		tmp = g_ptr_array_index (array, i);
-		g_ptr_array_index (array, i) = g_ptr_array_index (array, j);
-		g_ptr_array_index (array, j) = tmp;
-	}
-}
-
-
-int
-g_ptr_array_binary_search (GPtrArray    *array,
-			   gpointer      value,
-			   GCompareFunc  func)
-{
-	int l, r, p, cmp = -1;
-		
-	l = 0;
-	r = array->len;
-	while (l < r) {
-		p = l + ((r - l) / 2);
-		cmp = func(value, &g_ptr_array_index (array, p));
-		if (cmp == 0)
-			return p; 
-		else if (cmp < 0)
-			r = p;
-		else 
-			l = p + 1;
-	}
-	
-	return -1;
-}
-
-
 GHashTable *static_strings = NULL;
 
 
@@ -646,58 +530,15 @@ char*
 g_uri_display_basename (const char  *uri)
 {
 	char *e_name, *name;
-	
+
 	e_name = g_filename_display_basename (uri);
 	name = g_uri_unescape_string (e_name, "");
 	g_free (e_name);
-	
+
 	return name;
 }
 
 
-char **
-_g_strv_prepend (char **str_array,
-                 const char *str)
-{
-       char **result;
-       int i;
-       int j;
-
-       result = g_new (char *, g_strv_length (str_array) + 1);
-       i = 0;
-       result[i++] = g_strdup (str);
-       for (j = 0; str_array[j] != NULL; j++)
-               result[i++] = g_strdup (str_array[j]);
-       result[i] = NULL;
-
-       return result;
-}
-
-
-gboolean
-_g_strv_remove (char **str_array,
-               const char *str)
-{
-        int i;
-        int j;
-
-        if (str == NULL)
-                return FALSE;
-
-        for (i = 0; str_array[i] != NULL; i++)
-                if (strcmp (str_array[i], str) == 0)
-                        break;
-
-        if (str_array[i] == NULL)
-                return FALSE;
-
-        for (j = i; str_array[j] != NULL; j++)
-                str_array[j] = str_array[j + 1];
-
-        return TRUE;
-}
-
-
 const gchar *
 _g_path_get_file_name (const gchar *file_name)
 {
@@ -728,7 +569,7 @@ _g_path_get_base_name (const char *path,
 		       const char *base_dir,
 		       gboolean    junk_paths)
 {
-	int         base_dir_len;
+	size_t      base_dir_len;
 	const char *base_path;
 
 	if (junk_paths)
