@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -33,8 +33,6 @@
 
 #include "fr-init.h"
 
-gint          ForceDirectoryCreation;
-
 static char **remaining_args;
 static char  *add_to = NULL;
 static int    add;
@@ -43,6 +41,13 @@ static int    extract;
 static int    extract_here;
 static char  *default_url = NULL;
 
+static void
+_print_version_and_exit (const gchar *option_name, const gchar *value, gpointer data, GError *error)
+{
+	g_print("%s %s\n", _("Engrampa Archive Manager"), VERSION);
+	exit (EXIT_SUCCESS);
+}
+
 /* argv[0] from main(); used as the command to restart the program */
 static const char *program_argv0 = NULL;
 
@@ -75,6 +80,11 @@ static const GOptionEntry options[] = {
 	  N_("Create destination folder without asking confirmation"),
 	  NULL },
 
+	{ "version", 0, G_OPTION_FLAG_NO_ARG,
+	  G_OPTION_ARG_CALLBACK, _print_version_and_exit,
+	  N_("Show the application's version"),
+	  NULL },
+
 	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &remaining_args,
 	  NULL,
 	  NULL },
